@@ -1,9 +1,10 @@
 package Resque;
 {
-  $Resque::VERSION = '0.11';
+  $Resque::VERSION = '0.12';
 }
-use Any::Moose;
-use Any::Moose '::Util::TypeConstraints';
+use Moose;
+use Moose::Util::TypeConstraints;
+with 'Resque::Pluggable';
 
 # ABSTRACT: Redis-backed library for creating background jobs, placing them on multiple queues, and processing them later.
 
@@ -44,7 +45,7 @@ has failures => (
 has worker => (
     is      => 'ro',
     lazy    => 1,
-    default => sub { Resque::Worker->new( resque => $_[0] ) }
+    default => sub { $_[0]->worker_class->new( resque => $_[0] ) }
 );
 
 sub push {
@@ -120,10 +121,10 @@ sub new_job {
     my ( $self, $job ) = @_;
 
     if ( $job && ref $job && ref $job eq 'HASH' ) { 
-         return Resque::Job->new({ resque => $self, %$job }); 
+         return $self->job_class->new({ resque => $self, %$job }); 
     }
     elsif ( $job ) {
-        return Resque::Job->new({ resque => $self, payload => $job });
+        return $self->job_class->new({ resque => $self, payload => $job });
     }
     confess "Can't build an empty Resque::Job object.";
 }
@@ -173,7 +174,7 @@ Resque - Redis-backed library for creating background jobs, placing them on mult
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -243,18 +244,16 @@ Accept a Redis object or string. When a string is
 passed in, it will be used as Redis server argument.
 
 =head2 namespace
-
 This is useful to run multiple queue systems with the same Redis backend.
 
 By default 'resque' is used.
 
 =head2 failures
-
 Failures handler. See L<Resque::Failures>.
 
 =head2 worker
-
 A L<Resque::Worker> on this resque instance.
+It can have plugin/roles applied. See L<Resque::Pluggable>.
 
 =head1 METHODS
 
@@ -273,13 +272,11 @@ Example
     $resque->push( archive => { class => 'Archive', args => [ 35, 'tar' ] } )
 
 =head2 pop
-
 Pops a job off a queue. Queue name should be a string.
 
 Returns a Resque::Job object.
 
 =head2 size
-
 Returns the size of a queue.
 Queue name should be a string.
 
@@ -299,11 +296,9 @@ To get the 3rd page of a 30 item, paginatied list one would use:
     $resque->peek('my_queue', 59, 30)
 
 =head2 queues
-
 Returns an array of all known Resque queues.
 
 =head2 remove_queue
-
 Given a queue name, completely deletes the queue.
 
 =head2 mass_dequeue
@@ -341,17 +336,17 @@ memory intensive, depending on the size of your queue, as it loads
 all jobs into an array before processing.
 
 =head2 new_job
+Build a L<Resque::Job> object on this system for the given
+hashref or string(payload for object).
 
-Build a Resque::Job object on this system for the given
-hashref(see Resque::Job) or string(payload for object).
+L<Resque::Job> class can be extended thru roles/plugins. 
+See L<Resque::Pluggable>.
 
 =head2 key
-
 Concatenate $self->namespace with the received array of names
 to build a redis key name for this resque instance.
 
 =head2 keys
-
 Returns an array of all known Resque keys in Redis. Redis' KEYS operation
 is O(N) for the keyspace, so be careful - this can be slow for big databases.
 
@@ -386,20 +381,16 @@ what you've fixed.
 
 =item *
 
+Improve docs for plugin authors
+
+=item *
+
 A generic runner for attaching workers to queues.
 
 =item *
 
-Implement all or most of the callbacks the ruby library has.
-
-=item *
-
 Find a way to test worker fork and signal handling.
 
-=item *
-
-Improve docs.
-
 =back
 
 =head1 SEE ALSO
